        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 26 <strong>control</strong><br>0,1,3,8,11,13,14,17,20,21,22,23,24,28,29,32,33,34,35,37,39,42,44,46,48,49';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>38</strong> miembros: 16 <br>2,4,5,7,10,18,25,26,31,36,38,41,43,45,47,50';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>40</strong> miembros: 9 <br>6,9,12,15,16,19,27,30,40';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 26 <strong>control</strong><br>0,1,3,8,11,13,14,17,20,21,22,23,24,28,29,32,33,34,35,37,39,42,44,46,48,49';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>38</strong> miembros: 16 <br>2,4,5,7,10,18,25,26,31,36,38,41,43,45,47,50';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>40</strong> miembros: 9 <br>6,9,12,15,16,19,27,30,40';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 26 <strong>control</strong><br>0,1,3,8,11,13,14,17,20,21,22,23,24,28,29,32,33,34,35,37,39,42,44,46,48,49';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>38</strong> miembros: 16 <br>2,4,5,7,10,18,25,26,31,36,38,41,43,45,47,50';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>40</strong> miembros: 9 <br>6,9,12,15,16,19,27,30,40';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 26 <strong>control</strong><br>0,1,3,8,11,13,14,17,20,21,22,23,24,28,29,32,33,34,35,37,39,42,44,46,48,49';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>38</strong> miembros: 16 <br>2,4,5,7,10,18,25,26,31,36,38,41,43,45,47,50';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>40</strong> miembros: 9 <br>6,9,12,15,16,19,27,30,40';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 26 <strong>control</strong><br>0,1,3,8,11,13,14,17,20,21,22,23,24,28,29,32,33,34,35,37,39,42,44,46,48,49';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>38</strong> miembros: 16 <br>2,4,5,7,10,18,25,26,31,36,38,41,43,45,47,50';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>40</strong> miembros: 9 <br>6,9,12,15,16,19,27,30,40';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 26 <strong>control</strong><br>0,1,3,8,11,13,14,17,20,21,22,23,24,28,29,32,33,34,35,37,39,42,44,46,48,49';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>38</strong> miembros: 16 <br>2,4,5,7,10,18,25,26,31,36,38,41,43,45,47,50';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260519 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>40</strong> miembros: 9 <br>6,9,12,15,16,19,27,30,40';}
}
